@@ -1,6 +1,6 @@
 # ClamTk, copyright (C) 2004-2016 Dave M
 #
-# This file is part of ClamTk (https://github.com/dave-theunsub/clamtk/wiki).
+# This file is part of ClamTk (https://dave-theunsub.github.io/clamtk).
 #
 # ClamTk is free software; you can redistribute it and/or modify it
 # under the terms of either:
@@ -192,6 +192,11 @@ sub filter {
     # https://github.com/dave-theunsub/clamtk/issues/59
     $directive .= ' --scan-archive=yes';
 
+    # Increase maximum amount of data to scan for each container file;
+    # goes hand in hand with the $directive above
+    # https://github.com/dave-theunsub/clamtk/issues/59
+    $directive .= ' --max-scansize=500M';
+
     # By default, we ignore .gvfs directories.
     # Once we figure out KDE's process, we'll exclude that too.
     #<<<
@@ -214,7 +219,12 @@ sub filter {
         )
     {
         # warn "excluding $ignore\n";
-        $directive .= " --exclude-dir=" . quotemeta( $ignore );
+        # --exclude-dir=REGEX  Don't scan directories matching REGEX
+        # Using REGEX is important because users could have some
+        # of the whitelisted domains as part of a directory that
+        # should be scanned.
+        # Github #61 - https://github.com/dave-theunsub/clamtk/issues/61
+        $directive .= " --exclude-dir=^" . quotemeta( $ignore );
     }
 
     # Remove mail directories for now -
